@@ -1,9 +1,9 @@
 mod print;
 mod search;
+mod searchresult;
 mod structs;
-// mod bumpalo_herd;
 
-#[cfg(not(test))]
+#[cfg(not(any(test, miri)))]
 #[global_allocator]
 static GLOBAL: mimalloc::MiMalloc = mimalloc::MiMalloc;
 
@@ -44,8 +44,7 @@ macro_rules! perf {
 
 fn main() -> std::io::Result<()> {
     let search = structs::Cli::run();
-    std::env::set_var("RUST_MIN_STACK", format!("{}", 1024 * 1024 * 1024));
-
+    
     perf! {
         ctx = "search";
         let buffers = search.search();
